package com.ruoyi.mall.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.mall.domain.MallShopShop;
import com.ruoyi.mall.domain.vo.CascaderVO;

/**
 * 商家管理Service接口
 *
 * @author ruoyi
 * @date 2024-03-28
 */
public interface IMallShopShopService
{
    /**
     * 查询商家管理
     *
     * @param shopId 商家管理主键
     * @return 商家管理
     */
    public MallShopShop selectMallShopShopByShopId(Long shopId);

    /**
     * 查询商家管理列表
     *
     * @param mallShopShop 商家管理
     * @return 商家管理集合
     */
    public List<MallShopShop> selectMallShopShopList(MallShopShop mallShopShop);

    /**
     * 新增商家管理
     *
     * @param mallShopShop 商家管理
     * @return 结果
     */
    public int insertMallShopShop(MallShopShop mallShopShop);

    /**
     * 修改商家管理
     *
     * @param mallShopShop 商家管理
     * @return 结果
     */
    public int updateMallShopShop(MallShopShop mallShopShop);

    /**
     * 批量删除商家管理
     *
     * @param shopIds 需要删除的商家管理主键集合
     * @return 结果
     */
    public int deleteMallShopShopByShopIds(Long[] shopIds);

    /**
     * 删除商家管理信息
     *
     * @param shopId 商家管理主键
     * @return 结果
     */
    public int deleteMallShopShopByShopId(Long shopId);

    /**
     * 根据商家名称查询商家管理
     *
     * @param shopName 商家名称
     * @return 商家管理
     */
    public MallShopShop selectMallShopShopByShopName(String shopName);

    /**
     * 根据商家账号查询商家管理
     *
     * @param shopAccount 商家账号
     * @return 商家管理
     */
    public MallShopShop selectMallShopShopByShopAccount(String shopAccount);

    /**
     * 根据系统用户ID查询商家管理
     *
     * @param sysUserId 系统用户ID
     * @return 商家管理
     */
    public MallShopShop selectMallShopShopBySysUserId(Long sysUserId);

    /**
     * 后台重置商家密码
     * @return 商家
     */
    public AjaxResult resetPassword(Map<String,Object> param);

    /**
     * 查询商家管理
     *
     * @param params 参数
     * @return 商家管理
     */
    public List<Map<String,Object>> getShopNearestDistance(Map<String,Object> params);

    /**
     * 商家列表,无经纬度
     * @return
     */
    public List<Map<String,Object>> queryShopList();

    /**
     * 所有店铺和供应商列表
     * @return
     */
    public List<CascaderVO> selectAllShopList();
}
